@@ -1,5 +1,5 @@
-## Copyright (C) 2016-2020 Carnë Draug <carandraug@octave.org>
-## Copyright (C) 2011-2021 Philip Nienhuis
+## Copyright (C) 2016-2025 Carnë Draug <carandraug@octave.org>
+## Copyright (C) 2011-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License as
@@ -19,6 +19,7 @@
 ## @deftypefn {} {} __exit_io_package__ ()
 ## Undocumented internal function of io package.
 ##
+## Deregister Qt help files for GUI doc browser.
 ## Remove io java jars loaded by io package functions from javaclasspath.
 ##
 ## @end deftypefn
@@ -26,11 +27,32 @@
 ## PKG_DEL: __exit_io__ ()
 
 function __exit_io__ ()
+
+  ## Package documentation
+  ## On package unload, attempt to unload docs
+  try
+    pkg_dir = fileparts (fullfile (mfilename ("fullpath")));
+    doc_file = fullfile (pkg_dir, "doc", "io.qch");
+    doc_file = strrep (doc_file, '\', '/');
+    if exist(doc_file, "file")
+      if exist("__event_manager_unregister_documentation__")
+        __event_manager_unregister_documentation__ (doc_file);
+      elseif exist("__event_manager_unregister_doc__")
+        __event_manager_unregister_doc__ (doc_file);
+      endif
+    endif
+  catch
+    # do nothing
+  end_try_catch
+
+  ## Java spreadsheet I/O jars.
   ## All we need to do is try to remove all Java spreadsheet class libs loaded
-  ## by chk_spreadsheet_support.m from the javaclasspath
+  ## by chk_spreadsheet_support.m from the javaclasspath ...
   try
     chk_spreadsheet_support ("", -1);
   catch
     warning ("Couldn't remove spreadsheet I/O javaclasspath entries while unloading io pkg\n");
   end_try_catch
+  ## .. followed by clearing binary modules.
+  clear -f cell2csv csv2cell col2num num2col csvconcat csvexplode
 endfunction
