@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -13,62 +13,69 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## calccelladdress (R, C) - compute spreadsheet style cell address from
+## -*- texinfo -*-
+## @deftypefn{function file} @var{celladdr} = calccelladdress (@var{row}, @var{column})
+##
+## calccelladdress (row, column) - compute spreadsheet style cell address from
 ## row & column index (both 1-based).
-## 
+##
 ## Max column index currently set to 18278 (max ODS: 1024, OOXML: 16384).
 ## Row limits for ODF and OOXML are 65536 and 1048576, resp.
+##
+## @end deftypefn
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-12-12
 
 function [ celladdress ] = calccelladdress (row, column)
 
-	if (nargin < 2) error ("calccelladdress: Two arguments needed") endif
-
-	if (column > 18278 || column < 1)
-    error ("Specified column out of range (1..18278)"); 
-  endif
-	if (row > 1048576 || row < 1)
-    error ('Specified row out of range (1..1048576)'); 
+  if (nargin < 2)
+    error ("calccelladdress: Two arguments needed");
   endif
 
-	celladdress = sprintf ("%s%d", num2col (column), row);
+  if (column > 18278 || column < 1)
+    error ("calccelladdress: specified column out of range (1..18278)");
+  endif
+  if (row > 1048576 || row < 1)
+    error ("calccelladdress: specified row out of range (1..1048576)");
+  endif
+
+  celladdress = sprintf ("%s%d", num2col (column), row);
 
 endfunction
 
 %!test
 %! a = calccelladdress (1, 1);
-%! assert (a, 'A1');
+%! assert (a, "A1");
 
 %!test
 %! a = calccelladdress (378, 28);
-%! assert (a, 'AB378');
+%! assert (a, "AB378");
 
 %!test
 %! a = calccelladdress (65536, 1024);
-%! assert (a, 'AMJ65536');
+%! assert (a, "AMJ65536");
 
 %!test
 %! a = calccelladdress (1048576, 16384);
-%! assert (a, 'XFD1048576');
+%! assert (a, "XFD1048576");
 
 %!test
 %! a = calccelladdress (378, 26);
-%! assert (a, 'Z378');
+%! assert (a, "Z378");
 
 %!test
 %! a = calccelladdress (378, 702);
-%! assert (a, 'ZZ378');
+%! assert (a, "ZZ378");
 
 %!test
 %! a = calccelladdress (378, 701);
-%! assert (a, 'ZY378');
+%! assert (a, "ZY378");
 
 %!test
 %! a = calccelladdress (378, 703);
-%! assert (a, 'AAA378');
+%! assert (a, "AAA378");
 
 %!test
 %! a = calccelladdress (378, 676);
-%! assert (a, 'YZ378');
+%! assert (a, "YZ378");
