@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2021 Philip Nienhuis
+## Copyright (C) 2009-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -33,19 +33,19 @@
 ## containing these classes. TAKE NOTICE: /forward/ slashes are needed!
 ## chk_spreadsheet_support() will recurse into at most two subdir levels;
 ## if the Java class libs are scattered across deeper subdir levels or
-## further apart in the file system, multiple calls to 
-## chk_spreadsheet_support may be required. @var{path_to_jars} can be [] 
+## further apart in the file system, multiple calls to
+## chk_spreadsheet_support may be required. @var{path_to_jars} can be []
 ## or '' if no class libs need to be added to the javaclasspath.
 ##
 ## @var{path_to_ooo} - installation directory of OpenOffice.org (again with
 ## /forward/ slashes). Usually that is something like (but no guarantees):
 ## @table @asis
-## - Windows: C:/Program Files/OpenOffice.org   or 
-##            C:/Program Files (X86)/LibreOffice
+## @item 'Windows': C:/Program Files/OpenOffice.org or <br>
+##  C:/Program Files (X86)/LibreOffice
 ##
-## - *nix: /usr/lib/ooo  or  /opt/libreoffice
+## @item '*nix': /usr/lib/ooo  or  /opt/libreoffice
 ##
-## - Mac OSX: ?????
+## @item 'Mac OSX': ?????
 ##
 ## IMPORTANT: @var{path_to_ooo} should be such that both:
 ## @example
@@ -59,7 +59,7 @@
 ## @end table
 ##
 ## (Note that LibreOffice/OOo should match the bit width (32bit or 64bit) of the
-## Java version Octave was built with.) 
+## Java version Octave was built with.)
 ##
 ## @var{debug_level}: (integer) between [0 (no output) .. 3 (full output]
 ## @table @asis
@@ -67,7 +67,7 @@
 ## @item 0
 ## No debug output is generated.
 ##
-## @item 1 
+## @item 1
 ## Only proper operation of main interface groups (COM, Java) is shown.
 ## If @var{path_to_jars} and/or @var{path_to_ooo} was supplied,
 ## chk_spreadsheet_support indicates whether it could find the required
@@ -87,10 +87,9 @@
 ##
 ## @item -1 (or any negative number)
 ## Remove all directories and Java class libs that chk_spreadsheet_support
-## added to the javaclasspath. If @var{debug_level} < 1 report number of 
+## added to the javaclasspath. If @var{debug_level} < 1 report number of
 ## removed javaclasspath entries; if @var{debug_level} < 2 report each
 ## individual removed entry.
-## @noindent
 ## @end table
 ##
 ## Output:
@@ -117,7 +116,7 @@
 ##         supported by LibreOffice/OOo)
 ## @end example
 ##
-## @var{INTFS}: listing of supported spreadsheet interfaces. The OCT 
+## @var{INTFS}: listing of supported spreadsheet interfaces. The OCT
 ## interface is always supported.
 ##
 ## @var{ljars}: listing of full paths of Java class libs and directories
@@ -136,7 +135,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
   persistent sinterfaces;                   ## Interfaces found to be supported
 
   sinterfaces = {"OCT"};
-  jcp = []; 
+  jcp = [];
   retval = 0;
   if (nargin < 3)
     path_to_ooo= "";
@@ -183,7 +182,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
     printf ("\n");
   endif
 
-  interfaces = {"COM", "POI", "POI+OOXML", "JXL", "OXS", "OTK", "JOD", "UNO", "OCT"}; 
+  interfaces = {"COM", "POI", "POI+OOXML", "JXL", "OXS", "OTK", "JOD", "UNO", "OCT"};
   ## Order  = vital
 
   ## Just mention OCT interface
@@ -352,9 +351,9 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
   jars_complete = isempty (missing);
   if (dbug)
     if (jars_complete)
-      printf ("All Java-based interfaces (save UNO) fully supported.\n\n");
+      printf ("\nAll Java-based interfaces (save UNO) fully supported.\n\n");
     else
-      printf ("Some class libs lacking yet...\n\n"); 
+      printf ("\nSome class libs lacking yet...\n\n");
     endif
   endif
 
@@ -392,7 +391,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
               ## Check if common-collections4 is req'd (only for POI >= 3.15)
               try
                 poiv = javaObject ("org.apache.poi.Version").getVersion();
-                if (compare_versions (poiv, "3.14", "<=") && 
+                if (compare_versions (poiv, "3.14", "<=") &&
                     strncmpi (tmpm{jj}, "commons-collections4", 8))
                   --targt;
                   --tmpmcnt;
@@ -441,7 +440,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
     endfor
     if (dbug)
       if (targt)
-        printf ("Some class libs still lacking...\n\n");
+        printf ("\nSome class libs still lacking...\n\n");
       endif
     endif
   endif
@@ -524,7 +523,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
         else
           if (dbug > 2)
             printf ("Suggested OpenOffice.org install directory: %s not found!\n", ...
-                     path_to_ooo); 
+                     path_to_ooo);
             return
           endif
         endif
@@ -542,7 +541,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
           ##    Find out the exact name of Basis.....
           basisdirlst = dir ([path_to_ooo filesep "?asis" "*"]);
           jj = 1;
-          if (numel (basisdirlst) > 0) 
+          if (numel (basisdirlst) > 0)
             while (jj <= size (basisdirlst, 1) && jj > 0)
               basisdir = basisdirlst(jj).name;
               if (basisdirlst(jj).isdir)
@@ -608,7 +607,7 @@ function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path
     endif
     if (dbug)
       if (targt)
-        printf ("Some UNO class libs still lacking...\n\n"); 
+        printf ("Some UNO class libs still lacking...\n\n");
       else
         printf ("UNO interface supported now.\n\n");
       endif
@@ -638,7 +637,7 @@ function [ ret_dir ] = get_dir_ (base_dir, req_dir)
     while (! ret_dir_list(idx(ii)).isdir)
       ii = ii + 1;
       if (ii > numel (idx))
-        return; 
+        return;
       endif
     endwhile
     ## If we get here, a dir with proper name has been found. Construct path
