@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2020 Philip Nienhuis
+## Copyright (C) 2009-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -94,7 +94,7 @@
 ##   [xlso, status] = oct2xls ('arr', xlsi, 'Third_sheet', 'AA31:AB278');
 ## @end example
 ##
-## @seealso {xls2oct, xlsopen, xlsclose, xlsread, xlswrite, xlsfinfo}
+## @seealso{xls2oct, xlsopen, xlsclose, xlsread, xlswrite, xlsfinfo}
 ##
 ## @end deftypefn
 
@@ -106,10 +106,10 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   if (nargin < 2)
     error ("oct2xls: needs a minimum of 2 arguments.");
   endif
-  
+
   ## Validate input array, make sure it is a cell array
   if (isempty (obj))
-    warning ("oct2xls: request to write empty matrix - ignored."); 
+    warning ("oct2xls: request to write empty matrix - ignored.");
     rstatus = 1;
     return;
   elseif (isnumeric (obj))
@@ -121,7 +121,7 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
     error ("oct2xls: input array neither cell nor numeric array\n");
   endif
   if (ndims (obj) > 2)
-    error ("oct2xls: only 2-dimensional arrays can be written to spreadsheet\n"); 
+    error ("oct2xls: only 2-dimensional arrays can be written to spreadsheet\n");
   endif
   ## Cast all numerical values to double as spreadsheets only have
   ## double/boolean/text type
@@ -173,14 +173,14 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
     endif
   endif
 
-  ## Various options 
+  ## Various options
   if (isempty (spsh_opts))
     spsh_opts.formulas_as_text = 0;
     spsh_opts.convert_utf = 0;
     ## other options to be implemented here
   elseif (isstruct (spsh_opts))
     if (! isfield (spsh_opts, "formulas_as_text"))
-      spsh_opts.formulas_as_text = 0; 
+      spsh_opts.formulas_as_text = 0;
     endif
     if (! isfield (spsh_opts, "convert_utf"))
       spsh_opts.convert_utf = 0;
@@ -189,7 +189,7 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   else
     error ("oct2xls: structure expected for arg #5\n");
   endif
-  
+
   if (nargout < 1)
     printf ("oct2xls: warning: no output spreadsheet file pointer specified.\n");
   endif
@@ -213,7 +213,7 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
       switch xls.odfvsn
         case "0.7.5"
           [ xls, rstatus ] = __OTK_oct2ods__ (obj, xls, wsh, crange, spsh_opts);
-        case {"0.8.6", "0.8.7", "0.8.8"}
+        case {"0.8.6", "0.8.7", "0.8.8", "0.10.0", "0.11.0", "0.12.0"}
           [ xls, rstatus ] = __OTK_oct2spsh__ (obj, xls, wsh, crange, spsh_opts);
         otherwise
           error ("oct2ods: unsupported odfdom version\n");
