@@ -1,4 +1,4 @@
-## Copyright (C) 2012-2018 Philip Nienhuis
+## Copyright (C) 2012-2025 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -65,7 +65,8 @@ function [ ods, odssupport, lastintf ] = __JOD_spsh_open__ (ods, rw, filename, o
       odssupport += 2;
       lastintf = "JOD";
     catch
-      error ("Couldn't open file %s using JOD", filename);
+      error ("xlsopen: couldn't open file %s using JOD", filename);
+  	  lastintf = "";
     end_try_catch
 
 endfunction
