@@ -1,5 +1,5 @@
-## Copyright (C) 2013-2020 Markus Bergholz
-## Parts Copyright (C) 2014-2020 Philip Nienhuis
+## Copyright (C) 2013-2025 Markus Bergholz
+## Parts Copyright (C) 2014-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -98,10 +98,13 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
   else
     ## Get all data in sheet and row/column limits. If wsh is numeric,
     ## __OCT_xlsx2oct__ will turn it into a valid worksheet no.
+    o_spsh_opts = spsh_opts;
+    spsh_opts.formulas_as_text = true;
     [rawarr, xls]  = __OCT_xlsx2oct__ (xls, wsh, "", spsh_opts);
+    spsh_opts = o_spsh_opts;
     lims = xls.limits;
   endif
-  
+
   ## Merge old and new data. Provisionally allow empty new data to wipe old data
   [rawarr, lims, onr, onc] = __OCT_merge_data__ (rawarr, lims, arrdat, obj_dims);
 
@@ -203,7 +206,9 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
       partname = sprintf (partname, wsh_number);
       ## Find last worksheet node & insert new node
       srchstr = 'worksheet+xml"/>';
-      ipos = strfind (txml, srchstr)(end) + length (srchstr);
+      [~, ipos] = regexp (txml, '(worksheet\+xml".*?/>)');
+      ipos = ipos(end) + 1;
+#     ipos = strfind (txml, srchstr)(end) + length (srchstr);
       tid = fopen ([xls.workbook filesep "[Content_Types].xml"], "w");
       fprintf (tid, "%s", txml(1:ipos-1));
       fprintf (tid, partname);
@@ -214,35 +219,38 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
 
     ## === <docProps/app.xml> ===
     aid = fopen ([xls.workbook filesep "docProps" filesep "app.xml"], "r+");
-    axml = fread (aid, Inf, "char=>char").';
-    fclose (aid);
-    wshnode = sprintf ('<vt:lpstr>%s</vt:lpstr>', wsh_string);
-    if (xls.changed == 3)
-      [vt, is, ie] = getxmlnode (axml, "TitlesOfParts");
-      ## Just replace Sheet1 entry by new name
-      vt = strrep (vt, '>Sheet1<', ['>' wsh_string '<']);
-    else
-      ## 1. Update HeadingPairs node
-      [vt1, is, ie] = getxmlnode (axml, "HeadingPairs");
-      ## Bump number of entries
-      nshts = str2double (getxmlnode (vt1, "vt:i4", [], 1)) + 1;
-      vt1 = regexprep (vt1, '<vt:i4>(\d+)</vt:i4>', ["<vt:i4>" sprintf("%d", nshts) "</vt:i4>"]);
-      ## 2. Update TitlesOfParts node
-      [vt2, ~, ie] = getxmlnode (axml, "TitlesOfParts", ie);
-      ## Bump number of entries
-      nshts = str2double (getxmlattv (vt2, "size")) + 1;
-      vt2 = regexprep (vt2, 'size="(\d+)"', ['size="' sprintf("%d", nshts) '"']);
-      ## Add new worksheet entry
-      vt2 = regexprep (vt2, "</vt:lpstr>\s*</vt:vector>", ["</vt:lpstr>" wshnode "</vt:vector>"]);
-      vt = [vt1 vt2];
+    if (aid > 0)
+      ## Apparently a docProps/ subdir in .xlsx file. Isn't always written by Excel
+      axml = fread (aid, Inf, "char=>char").';
+      fclose (aid);
+      wshnode = sprintf ('<vt:lpstr>%s</vt:lpstr>', wsh_string);
+      if (xls.changed == 3)
+        [vt, is, ie] = getxmlnode (axml, "TitlesOfParts");
+        ## Just replace Sheet1 entry by new name
+        vt = strrep (vt, '>Sheet1<', ['>' wsh_string '<']);
+      else
+        ## 1. Update HeadingPairs node
+        [vt1, is, ie] = getxmlnode (axml, "HeadingPairs");
+        ## Bump number of entries
+        nshts = str2double (getxmlnode (vt1, "vt:i4", [], 1)) + 1;
+        vt1 = regexprep (vt1, '<vt:i4>(\d+)</vt:i4>', ["<vt:i4>" sprintf("%d", nshts) "</vt:i4>"]);
+        ## 2. Update TitlesOfParts node
+        [vt2, ~, ie] = getxmlnode (axml, "TitlesOfParts", ie);
+        ## Bump number of entries
+        nshts = str2double (getxmlattv (vt2, "size")) + 1;
+        vt2 = regexprep (vt2, 'size="(\d+)"', ['size="' sprintf("%d", nshts) '"']);
+        ## Add new worksheet entry
+        vt2 = regexprep (vt2, "</vt:lpstr>\s*</vt:vector>", ["</vt:lpstr>" wshnode "</vt:vector>"]);
+        vt = [vt1 vt2];
+      endif
+      ## Re(/over-)write apps.xml
+      aid = fopen ([xls.workbook filesep "docProps" filesep "app.xml"], "w+");
+      fprintf (aid, "%s", axml(1:is-1));
+      fprintf (aid, "%s", vt);
+      fprintf (aid, "%s", axml(ie+1:end));
+      fclose (aid);
+      ## === End of docProps/app.xml & axml ===
     endif
-    ## Re(/over-)write apps.xml
-    aid = fopen ([xls.workbook filesep "docProps" filesep "app.xml"], "w+");
-    fprintf (aid, "%s", axml(1:is-1));
-    fprintf (aid, "%s", vt);
-    fprintf (aid, "%s", axml(ie+1:end));
-    fclose (aid);
-  ## === End of docProps/app.xml & axml ===
 
   else
     ## when writing data to existing worksheets, MS-Excel might complain about
@@ -252,7 +260,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
       unlink ([xls.workbook filesep "xl" filesep "calcChain.xml"]);
     catch
     end_try_catch
-  
+
   endif
 
   ## If needed update sharedStrings entries xml descriptor files
@@ -294,27 +302,34 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
 
   ## === /docProps/core.xml (user/modifier info & date/time) ===
   cid = fopen ([xls.workbook filesep "docProps" filesep "core.xml"], "r+");
-  cxml = fread (cid, Inf, "char=>char").';
-  fclose (cid);
-  cxml = regexprep (cxml, 'dBy>(\w+)</cp:lastM', 'dBy>GNU Octave</cp:lastM');
-  modtime = int32 (datevec (now));
-  modtime = sprintf ("%4d-%2d-%2dT%2d:%2d:%2dZ", modtime(1), modtime(2), modtime(3), ...
-                                                 modtime(4), modtime(5), modtime(6));
-  modtime = strrep (modtime, " ", "0");
-  [modf, ia, ib] = getxmlnode (cxml, "dcterms:created", [], 1);
-  cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
-  [modf, ia, ib] = getxmlnode (cxml, "dcterms:modified", [], 1);
-  ## Possible LO bug (see Octave bug #45915) - "dcterms:modified" node may lack
-  if (isempty (modf))
-    ia = ib = index (cxml, "<cp:revision>");
-    cxml = [ cxml(1:ia-1) '<dcterms:modified xsi:type="dcterms:W3CDTF">2015-09-10T19:53:40Z</dcterms:modified><' cxml(ib+1:end) ];
+  if (cid > 0)
+    ## Apparently a docProps/ subdir in .xlsx file. Isn't always written by Excel
+    cxml = fread (cid, Inf, "char=>char").';
+    fclose (cid);
+    cxml = regexprep (cxml, 'dBy>(\w+)</cp:lastM', 'dBy>GNU Octave</cp:lastM');
+    modtime = int32 (datevec (now));
+    modtime = sprintf ("%4d-%2d-%2dT%2d:%2d:%2dZ", modtime(1), modtime(2), modtime(3), ...
+                                                   modtime(4), modtime(5), modtime(6));
+    modtime = strrep (modtime, " ", "0");
+    ## Update creation time for new file. Octave's template has the relevant node
+    if (xls.changed == 3)
+      [modf, ia, ib] = getxmlnode (cxml, "dcterms:created", [], 1);
+      cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
+    endif
+    ## Update modify time. Octave's template has the relevant node
     [modf, ia, ib] = getxmlnode (cxml, "dcterms:modified", [], 1);
+    ## Possible LO bug (see Octave bug #45915) - "dcterms:modified" node may lack
+    if (isempty (modf))
+      ia = ib = index (cxml, "<cp:revision>");
+      cxml = [ cxml(1:ia-1) '<dcterms:modified xsi:type="dcterms:W3CDTF">2015-09-10T19:53:40Z</dcterms:modified><' cxml(ib+1:end) ];
+      [modf, ia, ib] = getxmlnode (cxml, "dcterms:modified", [], 1);
+    endif
+    cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
+    cid = fopen ([xls.workbook filesep "docProps" filesep "core.xml"], "w+");
+    fprintf (cid, "%s", cxml);
+    fclose (cid);
+    ## === End of docProps/core.xml & cxml ===
   endif
-  cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
-  cid = fopen ([xls.workbook filesep "docProps" filesep "core.xml"], "w+");
-  fprintf (cid, "%s", cxml);
-  fclose (cid);
-  ## === End of docProps/core.xml & cxml ===
 
   ## Update status
   xls.changed = max (xls.changed-1, 1);
@@ -375,7 +390,7 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
                lims(1, 1), lims(1, 2));
       for c = 1:columns (arrdat)
         if (0 == isnan (arrdat{r, c}))
-          fprintf (fid, sprintf ('<c r="%s%d" t="n"><v>%0.15g</v></c>', ... 
+          fprintf (fid, sprintf ('<c r="%s%d" t="n"><v>%0.15g</v></c>', ...
                    num2col (c+lims(1, 1)-1), r+lims(2, 1)-1, arrdat{r, c}));
         endif
       endfor
