@@ -1,15 +1,15 @@
-## Copyright (C) 2012-2019 Philip Nienhuis <prnienhuis@users.sf.net>
-## 
+## Copyright (C) 2012-2025 Philip Nienhuis <prnienhuis@users.sf.net>
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
@@ -28,7 +28,7 @@ function [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filenam
         ! isempty (strfind (filename, "www://"  )))
       ## Seems in proper shape for OOo (at first sight)
     else
-      ## Transform into URL form. 
+      ## Transform into URL form.
       ## FIXME on Windows, make_absolute_filename() doesn't work across
       ##       drive(-letters) so until it is (ever) fixed we'll fall back on
       ##       canonicalize_file_name() there.
@@ -97,11 +97,8 @@ function [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filenam
       ## Check if we have a 32 vs. 64 bit clash
       printf ("\nOops, Octave hit an error.\n");
       ## Newer Octave-4.1.0+ has ENABLE_64, older Octave has USE_64_BIT_IDX_T
-      try
-        amd64y = strcmpi (octave_config_info ("USE_64_BIT_IDX_T"), "yes");
-      catch
-        amd64y = octave_config_info.ENABLE_64;
-      end_try_catch
+      [~, maxsize] = computer ();
+      amd64y = maxsize > 2^31 - 1;
       if (amd64y || ! isempty (strfind (lower (computer ("arch")), "x86_64")))
         printf ("Maybe you have 32-bit Libre/OpenOffice installed?\n");
         printf ("64-bit Octave requires 64-bit L.O. / OOo.\n\n");
@@ -109,7 +106,8 @@ function [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filenam
         printf ("Maybe you have 64-bit Libre/OpenOffice installed?\n");
         printf ("32-bit Octave requires 32-bit L.O. / OOo.\n\n");
       endif
-      error ("Couldn't open file %s using UNO\n", filename);
+      lastintf = "";
+      error ("xlsopen: couldn't open file %s using UNO\n", filename);
     end_try_catch
 
 endfunction
