@@ -1,4 +1,5 @@
-## Copyright (C) 2013-2019 Darien Pardinas Diaz <darien.pardinas-diaz@monash.edu>
+## Copyright (C) 2013-2025 Darien Pardinas Diaz <darien.pardinas-diaz@monash.edu>
+## Copyright (C) 2025 Philip Nienhuis <prnienhuis@users.sf.net>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -13,33 +14,41 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn{function file} @var{s} = read_namelist (@var{filename})
+##
 ## S = READ_NAMELIST (FILENAME) returns the struct S containing namelists and
 ## variables in the file FILENAME organised in hierachical way:
 ##
-##                |--VAR1
-##                |--VAR2
-##   |-- NMLST_A--|...
-##   |            |--VARNa
-##   |
-##   |            |--VAR1
-##   |-- NMLST_B--|--VAR2
-##   |            |...
+## @verbatim
+##                  |--VAR1
+##                  |--VAR2
+##     |-- NMLST_A--|...
+##     |            |--VARNa
+##     |
+##     |            |--VAR1
+##     |-- NMLST_B--|--VAR2
+##     |            |...
 ## S --|     ...    |--VARNb
 ##     |
 ##     |            |--VAR1
 ##     |-- NMLST_M--|--VAR2
 ##                  |...
 ##                  |--VARNm
+## @end verbatim
 ##
-## Note:  The function can read multidimensional variables as well. The  
-## function assumes that there is no more than one namelist section per 
-## line. At this time there is no syntax checking functionality so the 
+## Note:  The function can read multidimensional variables as well. The
+## function assumes that there is no more than one namelist section per
+## line. At this time there is no syntax checking functionality so the
 ## function will crash in case of errors.
 ##
-## Example:
+## @example:
 ##     NMLST = read_namelist ("OPTIONS.nam");
 ##     NMLST.NAM_FRAC.XUNIF_NATURE = 0.1;
 ##     write_namelist(NMlST, "MOD_OPTIONS.nam");
+## @end example
+##
+## @end deftypefn
 
 ## Written by:     Darien Pardinas Diaz (darien.pardinas-diaz@monash.edu)
 ## Version:        1.0
@@ -81,9 +90,9 @@ S = struct ();
   fclose (fid);
 
   ii = 0;
-  while (ii < c);    
+  while (ii < c);
     ## Find a record
-    ++ii; 
+    ++ii;
     line = lines{ii};
     idx = find (line == "&");
     if (! isempty (idx))   ## i.e. a namelist start
@@ -176,9 +185,9 @@ endfunction
 function S = parse_namelist (strng)
 
   ## Get all .true., .t. and .false., .f. to T and F
-  strng = regexprep (strng, '\.true\.' , "T", "ignorecase"); 
+  strng = regexprep (strng, '\.true\.' , "T", "ignorecase");
   strng = regexprep (strng, '\.false\.', "F", "ignorecase");
-  strng = regexprep (strng, '\.t\.', "T", "ignorecase"); 
+  strng = regexprep (strng, '\.t\.', "T", "ignorecase");
   strng = regexprep (strng, '\.f\.', "F", "ignorecase");
 
   ## Make evaluable the (:) expression in Octave if any
@@ -221,13 +230,13 @@ function S = parse_namelist (strng)
 
     if (kk > 1);
       arg_end(kk - 1) = ii;
-    endif    
+    endif
     vars{kk} = [ "S." strng(ii + 1: jj) ];
   endfor
 
   arg_end(end) = length (strng);
 
-  ## This variables are used in the eval function to evaluate True/False, 
+  ## This variables are used in the eval function to evaluate True/False,
   ## so don't remove it!
   T = ".true.";
   F = ".false.";
@@ -282,7 +291,7 @@ function [strng, is_lit] = parse_literal_strings (strng)
     if (strng(ii) == "'") ## Opening string with single quote...
       ++ii;
       while ((ii < len && strng(ii) != "'") || strcmp (strng(ii:ii+1), ''''''))
-        ++ii; 
+        ++ii;
         if strcmp (strng(ii-1:ii), ''''''),
           ++ii;
         endif
@@ -291,19 +300,19 @@ function [strng, is_lit] = parse_literal_strings (strng)
     if (strng(ii) == '"')  ## Opening string with double quote...
       strng(ii) = "'";     ## Change to single quote
       ++ii;
-      while (strng(ii) != '"' || strcmp (strng(ii:i+1),'""') && ii < len)
+      while (strng(ii) != '"' || strcmp (strng(ii:ii+1),'""') && ii < len)
         ## Check for a possible single quote here
         if (strng(ii) == "'")
           add_squote = [ add_squote ii ];
         endif
-        ++ii; 
+        ++ii;
         if (strcmp (strng(ii-1:ii), '""'))
           rem_dquote = [ rem_dquote ii-1 ];
           ++ii;
         endif
       endwhile
       strng(ii) = "'";     ## Change to single quote
-    endif   
+    endif
     ++ii;
   endwhile
   for ii = 1:length (add_squote);
@@ -322,7 +331,7 @@ function [strng, is_lit] = parse_literal_strings (strng)
     if (strng(ii) == "'")  ## Opening string with single quote...
       is_lit(ii) = 1;
       ++ii;
-      while ((ii < len && strng(ii) != "'") || strcmp (strng(ii:ii+1), "''")) 
+      while ((ii < len && strng(ii) != "'") || strcmp (strng(ii:ii+1), "''"))
         is_lit(ii) = 1;
         ++ii;
         if (strcmp (strng(ii-1:ii), '''''')),
@@ -330,7 +339,7 @@ function [strng, is_lit] = parse_literal_strings (strng)
           ++ii;
         endif
       endwhile
-      is_lit(ii) = 1;    
+      is_lit(ii) = 1;
     endif
     ++ii;
   endwhile
