@@ -1,33 +1,37 @@
-## Copyright (C) 2013-2017 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
+## Copyright (C) 2013-2025 Philip Nienhuis <prnienhuis at users.sf.net>
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} @var{filename} = rsearchfile (@var{dname}, @var{fname})
-## @deftypefnx {Function File} @var{filename} = rsearchfile (@var{dname}, @var{fname}, @var{maxdepth})
-## Recursively search for file or filename pattern FNAME starting in directory
-## DNAME and return the first match.
+## @deftypefn {Function File} @var{filename} = rfsearch (@var{dname}, @var{fnpattern})
+## @deftypefnx {Function File} @var{filename} = rfsearch (@var{dname}, @var{fnpattern}, @var{maxdepth})
+## Recursive File Search - search for file or filename pattern FNPATTERN starting
+## in directory DNAME and return the first match.
 ##
-## @var{dname} and @var{fname} must be character strings and should conform
+## @itemize
+## @item @var{dname}, @var{fnpattern}
+## Must be character strings and should conform
 ## to the directory name and filename requirements of your operating system.
-## Optional argument @var{maxdepth} can be specified to limit the maximum search
+##
+## @item @var{maxdepth} (optional) can be specified to limit the maximum search
 ## depth; the default value is 1 (search only in @var{dname} and subdirs of
 ## @var{dname}). Setting maxdepth to 0 limits the search to @var{dname}.
 ## Be careful with setting @var{maxdepth} to values > 3 or 4 as this can
 ## provoke excessive search times in densely populated directory trees.
 ## Keep in mind that rfsearch is a recursive function itself.
+## @end itemize
 ##
 ## Output argument @var{filename} returns the relative file path of the
 ## first match, relative to @var{DNAME}, or an empty character string if
@@ -46,7 +50,7 @@
 ## search subdirs of subdirs of /home
 ## @end example
 ##
-## @seealso {dir, glob}
+## @seealso{dir, glob}
 ##
 ## @end deftypefn
 
@@ -59,11 +63,11 @@ function [ fpath ] = rfsearch (dname, fname, mxdpth=1, depth=0)
   if (nargin < 2)
     print_usage ()
   elseif ((! ischar (dname)) || (! ischar (fname)))
-    error ("rsearchfile: character arguments expected for DNAME and FNAME\n");
+    error ("rfsearch: character arguments expected for DNAME and FNPATTERN\n");
   elseif (! isnumeric (mxdpth))
-    error ("Numeric value >= 0 expected for MAXDEPTH\n");
+    error ("rfsearch: numeric value >= 0 expected for MAXDEPTH\n");
   elseif (mxdpth < 0)
-    warning ("rsearchfile: negative value for MAXDEPTH (%d) set to 0\n", mxdpth);
+    warning ("rfsearch: negative value for MAXDEPTH (%d) set to 0\n", mxdpth);
     mxdpth = 0;
   elseif (! isnumeric (depth))
     print_usage ("too many or illegal arguments");
@@ -78,7 +82,7 @@ function [ fpath ] = rfsearch (dname, fname, mxdpth=1, depth=0)
   sbdir = '';
 
   fpath = dir ([dname filesep fname '*']);
-  if (isempty (fpath) && depth < mxdpth)
+  if ((fpath.isdir || isempty (fpath)) && depth < mxdpth)
     ## Bump search depth
     ++depth;
 
