@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2020 Philip Nienhuis
+## Copyright (C) 2009-2025 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -47,6 +47,8 @@
 ## the spreadsheet I/O interfaces that were found and/or are requested and
 ## active.  The default value is false (no info on interfaces is shown).
 ##
+## Spreadsheet I/O Interfaces
+## ==========================
 ## xlsopen works with interfaces, which are links to support software, mostly
 ## external. @*
 ## The built-in 'OCT' interface needs no external software and allows
@@ -56,7 +58,7 @@
 ## Currently implemented interfaces to external SW are (in order of preference)
 ## 'COM' (Excel/COM), 'POI' (Java/Apache POI), 'JXL' (Java/JExcelAPI), 'OXS'
 ## (Java/OpenXLS), 'UNO' (Java/OpenOffice.org - EXPERIMENTAL!), 'OTK'
-## (ODF Toolkit), 'JOD' (jOpendocument) or 'OCT' (native Octave); see below:
+## (ODF Toolkit), 'JOD' (jOpendocument); see below:
 ##
 ## @table @asis
 ## @item xls and .xlsx:
@@ -69,7 +71,6 @@
 ## priority. @*
 ## Excel'95 spreadsheets (BIFF5) can only be read using the JXL (JExcelAPI),
 ## UNO (Open-/LibreOffice), and  COM (Excel-ActiveX) interfaces.
-## @end item
 ##
 ## @item .ods, .sxc:
 ## A Java JRE plus one or more of (ODFtoolkit (version 0.7.5 or 0.8.6 - 0.8.8)
@@ -80,14 +81,39 @@
 ## lowest priority). @*
 ## The old OpenOffice.org .sxc format can be read using the UNO interface and
 ## older versions of the JOD interface.
-## @end item
 ##
 ## @item Other formats:
-## Apart from .gnumeric, by invoking the UNO interface one can read any format
-## that the installed LibreOffice version supports. The same goes (on Windows
-## systems) for MS-Excel.  However, writing to other file formats than .xlsx,
-## .ods, .gnumeric and .xls is not implemented.
-## @end item
+## By invoking the UNO interface one can read any format that the installed
+## LibreOffice version supports; see below. The same goes (on Windows systems)
+## for the COM interface (invoking MS-Excel).  However, writing to other file
+## formats than .xlsx, .ods and .xls is not implemented for COM.
+##
+## Depending on the installed LibreOffice release, in addition to .xls, .xlsx,
+## .ods and .sxc, the following file formats may be read/written (untested!)
+## when using the UNO interface.  The pertinent import/export filters are
+## inferred from the filename extension.
+##
+## @verbatim
+##   File format                           filename extension(s)
+##   ====================================  =====================
+##   "Gnumeric"                            .gnumeric, .gnm
+##   "Text CSV"                            .csv
+##   "UOF spreadsheet"                     .uos
+##   "OpenDocument Spreadsheet Flat XML"   .fods
+##   "dBase"                               .dbf
+##   "Digital Interchange Format"          .dif
+##   "Lotus 1-2-3"                         .wk1 .wk2 .123
+##   "WPS Lotus Calc"                      .wk3 .wk4
+##   "MS Works Calc"                       .wks, .wdb
+##   "ClarisWorks Calc"                    .cwk
+##   "Mac Works Calc"                      .wps
+##   "Quattro Pro 6.0"                     .wb2
+##   "WPS QPro Calc"                       .wb1 .wq1 .wq2
+##   "Rich Text Format (StarCalc)"         .rtf
+##   "SYLK"                                .slk .sylk
+##   "Apple Numbers"                       .numbers
+##   "Microsoft Multiplan"                 .mp
+## @end verbatim
 ## @end table
 ##
 ## The utility function chk_spreadsheet_support.m can be useful to set the
@@ -109,7 +135,7 @@
 ##    and the Apache POI interface are requested)
 ## @end example
 ##
-## @seealso {xlsclose, xlsread, xlswrite, xls2oct, oct2xls, xlsfinfo,
+## @seealso{xlsclose, xlsread, xlswrite, xls2oct, oct2xls, xlsfinfo,
 ## chk_spreadsheet_support}
 ##
 ## @end deftypefn
@@ -123,6 +149,12 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
   ## interfaces.<intf> = [] (not yet checked),
   ##                      0 (found to be unsupported or unwanted), or
   ##                      1 (checked and OK)
+
+  ## Define preferred order of (default) file extensions for if no extension
+  ## was specified
+  persistent prefext = {".xls", ".xlsx", ".xlsm", ".ods", ".gnumeric", ...
+                        ".gnm", ".csv"};
+
   if (isempty (chkintf) || (isnumeric (reqinterface) && reqinterface == -1))
     ## Either not yet checked, or selection to be reset to default
     chkintf = 1;
@@ -136,16 +168,17 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
     lastintf = "---";
   endif
   xlsintf_cnt = 1;
-
   ## Bit mask keeping track of detected/supported interfaces
   xlssupport = 0;
 
   ## Input checks
   if (nargout < 1)
-      error ("xlsopen: no return argument specified!\n usage:  XLS = xlsopen (Xlfile [, Rw] [, reqintf])\n");
+      error (["xlsopen: no return argument specified!\n", ...
+              "usage:  XLS = xlsopen (Xlfile [, Rw] [, reqintf])\n"]);
   endif
   if (! (islogical (xwrite) || isnumeric (xwrite)))
-      error ("xlsopen: numerical or logical value expected for arg ## 2 (readwrite)\n")
+      error (["xlsopen: numerical or logical value expected for arg ## 2 ", ...
+              "(readwrite)\n"]);
   endif
   if (ischar (filename))
     [pth, fnam, ext] = fileparts (filename);
@@ -163,10 +196,12 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
     error ("xlsopen: filename expected for argument #1");
   endif
 
+  ## Check available interfaces if none was specified now or in earlier call
   if (! isempty (reqinterface))
     intfmsg = "requested";
     if (! (ischar (reqinterface) || iscell (reqinterface)))
-      error ("xlsopen: arg. # 3 (interface) not recognized - character value required\n");
+      error (["xlsopen: arg. #3 (interface) not recognized - ", ...
+              "character value required\n"]);
     endif
     ## Turn arg3 into cell array if needed
     if (! iscell (reqinterface))
@@ -222,33 +257,9 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
   ## FIXME: invoke subfunct mtchext() rather than repeat below code several times
   ftype = 0;
   has_suffix = 1;
-  [sfxpos, ~, ~, ext] = regexpi (filename, '(\.xls[bmx]?|\.gnumeric|\.ods|\.scx|\.csv)');
-  if (! isempty (sfxpos))
-    ext = lower (ext{end});
-    ## Is .xls or .xls[x,m,b] or .ods or .gnumeric at right(most) position?
-    if (sfxpos(end) <= length (filename) - length (ext))
-      ## Apparently not, or it is an unrecognized extension
-      ## If xwrite = 0, check file suffix, else add .xlsx
-      has_suffix = 0;
-    else
-      switch ext
-        case ".xls"                       ## Regular (binary) BIFF
-          ftype = 1;
-        case {".xlsx", ".xlsm", ".xlsb"}  ## Zipped XML / OOXML. Catches xlsx, xlsb, xlsm
-          ftype = 2;
-        case ".ods"                       ## ODS 1.2 (Excel 2007+ & OOo/LO can read ODS)
-          ftype = 3;
-        case ".sxc"                       ## jOpenDocument (JOD) can read from
-          ftype = 4;                      ## .sxc files, but only if odfvsn = 2
-        case ".gnumeric"                  ## Zipped XML / gnumeric
-          ftype = 5;
-        case ".csv"                       ## csv. Detected for xlsread afficionados
-          ftype = 6;
-        otherwise
-          ## FIXME here should come the extraneous ones like .fods, .uos, .wk1, ...
-          warning ("xlsopen: file type ('%s' extension) not supported\n", ext);
-      endswitch
-    endif
+  [ftype, ~, ext] = __get_ftype__ (filename);
+  if (! isempty (ext))
+    ext = lower (ext);
   else
     has_suffix = 0;
   endif
@@ -269,14 +280,14 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
     fmode = "rb";
     if (! has_suffix)
       ## Try to find find an existing file with a recognized file extension
-      filnm = mtchext (filename);
+      filnm = mtchext (filename, prefext);
       if (! isempty (filnm))
         ## Simply choose the first one
         if (isstruct (filnm))
           filename = filnm(1).name;
         else
           filename = filnm;
-         endif
+        endif
       endif
     endif
   endif
@@ -292,8 +303,8 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[], verbose=false)
         xwrite = 3;
       else                          ## File exists, but isn't writable => Error
         fclose (fid);               ## Do not forget to close the handle neatly
-        error (sprintf ("xlsopen: write mode requested but file %s is not \
-writable\n", filename))
+        error (sprintf (["xlsopen: write mode requested but file %s is ", ...
+                        "not writable\n"], filename));
       endif
     endif
   else
@@ -309,8 +320,6 @@ writable\n", filename))
   if (! has_suffix && ! (interfaces.COM + interfaces.POI + ...
                          interfaces.JXL + interfaces.OXS + ...
                          interfaces.UNO))
-%    ## Just add 'x' - .xls was already added higher up
-%    filename = [filename "x"];
     ftype = 2;
   endif
 
@@ -373,11 +382,22 @@ writable\n", filename))
     if (verbose)
       printf ("   Invoking UNO ...");
     endif
-    ## Warn for LO / OOo stubbornness
-    if (ftype == 0 || ftype == 5 || ftype == 6)
-      warning ("UNO interface will write ODS format for unsupported file extensions\n")
-    endif
-    [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filename, xlssupport);
+    ## Part 1 of kludge to avoid lengthy delays while LO searches for printers
+    ## during aLoader.loadComponentFromURL (..., "_blank", ...) call below, only
+    ## req/d for .ods files
+    unwind_protect
+      if (ftype == 3)
+        SDDP = getenv ("SAL_DISABLE_DEFAULTPRINTER");
+        setenv ("SAL_DISABLE_DEFAULTPRINTER", "1");
+        ## Proceed with the JAVA-UNO bridge stuff
+      endif
+      [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filename, xlssupport);
+    unwind_protect_cleanup
+      ## Part 2: set env.var. to original value (or wipe it if it was empty)
+      if (ftype == 3)
+        setenv ("SAL_DISABLE_DEFAULTPRINTER", SDDP);
+      endif
+    end_unwind_protect
 
   elseif ((! xlssupport) && interfaces.OCT && ...
       (ftype == 2 || ftype == 3 || ftype == 5))
@@ -387,6 +407,12 @@ writable\n", filename))
     [ xls, xlssupport, lastintf ] = __OCT_spsh_open__ (xls, xwrite, filename, xlssupport, ftype);
   endif
 
+  ## Get Named Ranges, if any
+  try
+    xls.nmranges = getnmranges (xls);
+  catch
+  end_try_catch
+
   ## Rounding up. If none of the interfaces is supported we're out of luck.
   if (! xlssupport)
     if (isempty (reqinterface))
@@ -424,16 +450,17 @@ writable\n", filename))
 endfunction
 
 
-function fname = mtchext (fname)
-
-  ## Define preferred order of (default) file extensions
-  persistent prefext = {".xls", "xlsx", ".xlsm", ".ods", ".gnumeric", ".csv"};
+function fname = mtchext (fname, prefext)
 
   ## In case of multiple files with same name, pick the one with preferred ext.
   flist = {dir([fname ".*"]).name};
   exts = cell2mat (cell2mat (regexpi (flist, '.*(\.\w+$)', "tokens")));
   ## Get first matching file extension. ismember() arg order = vital!
-  ext = find (ismember (prefext, exts))(1);
-  fname = [fname ext];
+  extm = find (ismember (prefext, exts));
+  if (! isempty (extm))
+    fname = flist(extm);
+  else
+    fname = [fname prefext{1}];
+  endif
 
 endfunction
