@@ -1,5 +1,5 @@
-// Copyright (C) 2004-2020 Laurent Mazet <mazet@crm.mot.com>
-// Copyright (C) 2014-2021 Philip Nienhuis <prnienhuis@users.sf.net>
+// Copyright (C) 2004-2025 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2014-2025 Philip Nienhuis <prnienhuis@users.sf.net>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -192,8 +192,8 @@
 
 #define MAXSTRINGLENGTH 32768
 
-DEFUN_DLD (csv2cell, args, nargout, 
-          "-*- texinfo -*-\n\
+DEFUN_DLD (csv2cell, args, nargout,
+"-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {@var{c} = } csv2cell (@var{file})\n\
 @deftypefnx {Loadable Function} {@var{c} = } csv2cell (@var{file}, @var{sep})\n\
 @deftypefnx {Loadable Function} {@var{c} = } csv2cell (@var{file}, @var{sep}, @var{prot})\n\
@@ -236,8 +236,8 @@ The maximum line width of the csv file is set to 32768 characters.\n\
 (This is also the theoretical maximum number of columns - 1 in the data \n\
 if all fields are empty, i.e., a line containing just 32768 consecutive \n\
 separators will yield 32769 empty values.)\n\
-@end deftypefn") {
-
+@end deftypefn")
+{
   /* Get arguments */
   const int nargin = args.length ();
   octave_value_list retval;
@@ -246,7 +246,7 @@ separators will yield 32769 empty values.)\n\
       error ("csv2cell: not enough input arguments");
       return retval;
     }
-    
+
   const std::string file = octave::sys::file_ops::tilde_expand (args (0).string_value ());
 
   /* Look if first arg after filename = numeric. If yes => headerlines */
