@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2021 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2004-2025 Laurent Mazet <mazet@crm.mot.com>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -19,17 +19,20 @@
 #include "octave_4_2_compatibility.h"
 
 DEFUN_DLD (csvexplode, args, nargout,
-           "-*- texinfo -*-\n"
-           "@deftypefn {Loadable Function} {@var{c} =} csvexplode (@var{str})\n"
-           "@deftypefnx {Loadable Function} {@var{c} =} csvexplode (@var{str}, @var{sep})\n"
-           "@deftypefnx {Loadable Function} {@var{c} =} csvexplode (@var{str}, @var{sep}, @var{prot})\n"
-           "\n"
-           "Explode a CSV string into a cell. "
-           "@var{sep} (character value) changes the character used to separate two fields. "
-           "The default value is a comma (@code{,}). @var{prot} (character value) changes "
-           "the character used to protect a string. The default is a double quote (@code{\"}).\n"
-           "@end deftypefn") {
-
+"-*- texinfo -*-\n\
+@deftypefn {Loadable Function} {@var{c} =} csvexplode (@var{str})\n\
+@deftypefnx {Loadable Function} {@var{c} =} csvexplode (@var{str}, @var{sep})\n\
+@deftypefnx {Loadable Function} {@var{c} =} csvexplode (@var{str}, @var{sep}, @var{prot})\n\
+\n\
+Explode a CSV string into a cell.\n\
+\n\
+@var{sep} (character value) changes the character used to separate two fields.\
+The default value is a comma (@code{,}).\n\
+\n\
+@var{prot} (character value) changes the character used to protect a string.\n\
+The default is a double quote (@code{\"}).\n\
+@end deftypefn")
+          {
   /* Check argument */
   if ((args.length() < 1) || (args.length() > 3)) {
     print_usage ();
